=====================================
Installing OpenStack DNS as a Service
=====================================

.. toctree::
   :maxdepth: 2

   get_started
   install
   verify
   create-zone
   next-steps

This chapter assumes a working setup of OpenStack following the
`OpenStack Installation Tutorial <https://docs.openstack.org/install/>`_.

